@@ -22,7 +22,7 @@ def callback(
     ),
 ):
     """
-    metaDMG.
+    Welcome to metaDMG.
 
     First run the LCA and compute the ancient damage statistics with the 'compute' command:
 
@@ -348,5 +348,23 @@ def convert(
 #%%
 
 
+@cli_app.command("mismatch-to-mapDamage")
+def mismatch_to_mapDamage(
+    filename: Path = typer.Argument(
+        ...,
+        file_okay=True,
+        help="Path to the config-file.",
+    ),
+):
+    """Convert the mismatch file to mapDamage misincorporation.txt format."""
+
+    from metaDMG.fit import mismatch_to_mapDamage
+
+    mismatch_to_mapDamage.convert(filename=filename)
+
+
+#%%
+
+
 def cli_main():
     cli_app(prog_name="metaDMG")
